/* Diese Datei ist Teil von pmv-client <https://git.piratenpartei-sh.de>
 *
 * pmv-client ist Freie Software: Sie können es unter den Bedingungen
 * der GNU General Public License, wie von der Free Software Foundation,
 * Version 3 der Lizenz weiter verteilen und/oder modifizieren.
 *
 * Dieses Programm wird in der Hoffnung bereitgestellt, dass es nützlich sein
 * wird, jedoch OHNE JEDE GEWÄHR,; sogar ohne die implizite Gewähr der
 * MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 * Siehe die GNU General Public License für weitere Einzelheiten.
 *
 * Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 * Programm erhalten haben. Wenn nicht, siehe <https://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-only
 */

#include "configdialog.h"
#include "ui_configdialog.h"
#include "mainwindow.h"

#include <QSettings>
#include <QSqlQuery>
#include <QSqlQueryModel>
#include <QDebug>

ConfigDialog::ConfigDialog(QWidget *parent, Landesverband *lv) :
    QDialog(parent),
    ui(new Ui::ConfigDialog)
{
    ui->setupUi(this);

    // Marker für Entwicklungsmodus
    if (static_cast<MainWindow*>(parent)->development) {
        ui->label_develop->setText("Entwicklungsmodus aktiv");
    }

    // Lokale Einstellungen
    QSettings settings;
    ui->lineEdit_ImportDir->setText(settings.value("importdir").toString());
    ui->lineEdit_ExportDir->setText(settings.value("exportdir").toString());

    // Combobox mit den Bundesländern initialisieren
    QSqlQueryModel *model = new QSqlQueryModel;
    model->setQuery("SELECT ls, bezeichnung FROM bundesland ORDER BY bezeichnung");
    ui->comboBox_Bundesland->setModel(model);
    ui->comboBox_Bundesland->setModelColumn(1);
    // Suche den Index für den Länderschlüssel
    // WTF: Das muß doch eine bessere Möglichkeit geben als das hier!
    for (int i = 0; i < model->rowCount(); i++) {
        if (model->record(i).value("ls").toUInt() == lv->getBundeslandLs()) {
            ui->comboBox_Bundesland->setCurrentIndex(i);
            break;
        }
    }

    ui->lineEdit_prefix->setText(lv->getLVPrefix());
    ui->plainTextEdit->setPlainText(lv->getLVAdresse());
    ui->lineEdit_telefon->setText(lv->getLVTelefon());
    ui->lineEdit_mail->setText(lv->getLVMail());
    ui->spinBox_tmpnr->setValue(lv->getOffsetNrNeu());
    ui->spinBox_StdBeitrag->setValue(lv->getStdBeitrag());
    ui->lineEdit_IBAN->setText(lv->getLVIBAN());
    ui->lineEdit_BIC->setText(lv->getLVBIC());
    ui->lineEdit_Bank->setText(lv->getLVBank());

}


ConfigDialog::~ConfigDialog()
{
    delete ui;
}

void ConfigDialog::on_buttonBox_accepted()
{
    QSettings settings;
    settings.setValue("importdir", ui->lineEdit_ImportDir->text());
    settings.setValue("exportdir", ui->lineEdit_ExportDir->text());

}
