/* Diese Datei ist Teil von pmv-client <https://git.piratenpartei-sh.de>
 *
 * pmv-client ist Freie Software: Sie können es unter den Bedingungen
 * der GNU General Public License, wie von der Free Software Foundation,
 * Version 3 der Lizenz weiter verteilen und/oder modifizieren.
 *
 * Dieses Programm wird in der Hoffnung bereitgestellt, dass es nützlich sein
 * wird, jedoch OHNE JEDE GEWÄHR,; sogar ohne die implizite Gewähr der
 * MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 * Siehe die GNU General Public License für weitere Einzelheiten.
 *
 * Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 * Programm erhalten haben. Wenn nicht, siehe <https://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-only
 */

#include "landesverband.h"

#include <QSqlDatabase>
#include <QSqlQuery>
#include <QVariant>
#include <QDebug>

Landesverband::Landesverband()
{
    initialized = false;
    version = "0.0.0";
    releasedate = QDate(2022, 1, 1);
    lvprefix = "XXX";
    lvadresse = "";
    lvtelefon = "+49-40-12345678";
    lvmail = "noreply@example.com";
    offsetnrneu = 2000000;
    bundesland = "XX";
    bundesland_ls = 0;
    lviban = "";
    lvbic = "";
    lvbank = "";
    stdbeitrag = 0;
}

Landesverband::~Landesverband() {
    initialized = false;
}

bool Landesverband::loadFromDatabase() {
    QSqlQuery qry;
    qry.exec("SELECT globname, datentyp, beschreibung, wert FROM global");
    while (qry.next()) {
        if (qry.value("globname") == "Version") {
            version = qry.value("wert").toString();
        }
        if (qry.value("globname") == "ReleaseDate") {
            releasedate = qry.value("wert").toDate();
        }
        else if (qry.value("globname").toString() == "LVPrefix") {
            lvprefix = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "LVAdresse") {
            lvadresse = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "LVTelefon") {
            lvtelefon = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "LVMail") {
            lvmail = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "OffsetNrNeu") {
            offsetnrneu = qry.value("wert").toUInt();
        }
        else if (qry.value("globname").toString() == "Bundesland") {
            bundesland = qry.value("wert").toString();
            QSqlQuery qry2;
            qry2.prepare("SELECT ls FROM bundesland WHERE kuerzel=:k");
            qry2.bindValue(":k", bundesland);
            qry2.exec();
            qry2.first();
            bundesland_ls = qry2.value("ls").toUInt();
        }
        else if (qry.value("globname").toString() == "LVIBAN") {
            lviban = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "LVBIC") {
            lvbic = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "LVBank") {
            lvbank = qry.value("wert").toString();
        }
        else if (qry.value("globname").toString() == "StdBeitrag") {
            stdbeitrag = qry.value("wert").toUInt();
        }
    }
    initialized = true;
    return true;
}

bool Landesverband::isInitialized() {
    return initialized;
}

QString Landesverband::getVersion() {
    return version;
}

QDate Landesverband::getReleaseDate() {
    return releasedate;
}

QString Landesverband::getLVAdresse() {
    return lvadresse;
}

QString Landesverband::getLVTelefon() {
    return lvtelefon;
}

QString Landesverband::getLVMail() {
    return lvmail;
}

QString Landesverband::getLVPrefix() {
    return lvprefix;
}

uint Landesverband::getOffsetNrNeu() {
    return offsetnrneu;
}

uint Landesverband::getBundeslandLs() {
    return bundesland_ls;
}

QString Landesverband::getLVIBAN() {
    return lviban;
}

QString Landesverband::getLVBIC() {
    return lvbic;
}

QString Landesverband::getLVBank() {
    return lvbank;
}

uint Landesverband::getStdBeitrag() {
    return stdbeitrag;
}
